\name{all.regs}
\alias{all.regs}
\title{
  Goodness of fit measures for a regression hierarchy
}
\description{
  Calculates goodness of fit measures for regressions of a single
  dependent variable to all combinations of N independent variables
}
\usage{
all.regs(y, xcan, family = "gaussian", gof = "RMSPE", print.vars = FALSE)
}
\arguments{
  \item{y}{
    a vector containing the dependent variables
  }
  
  \item{xcan}{
    a dataframe containing the n independent variables
  }
  
  \item{family}{
    family argument of \code{glm}
  }

  \item{gof}{
    Goodness-of-fit measure.  Currently "RMSPE", Root-mean-square
    'prediction' error,  "logLik", Log-Likelihood or "Rsqu", R-squared
    }

  \item{print.vars}{
    if FALSE, the function returns a vector of goodness-of-fit measures. If
    TRUE, a data frame is returned with first column listing variable
    combinations and the second column listing goodness-of-fit measures.
    }
  }

\details{
This function calculates goodness of fit measures for the entire
hierarchy of models using all combinations of N dependent variables, and
returns them as an ordered list ready for input into the function
\code{partition}. This function requires the gtools package in
the gregmisc bundle      
}

\value{
  \item{gfs}{
    If print.vars is FALSE, a vector of goodness of fit measures for all
    combinations of independent varaiables in the hierarchy or, if
    print.vars is TRUE, a data frame listing all combinations of
    independent variables in the first column in ascending order, and
    the corresponding goodness of fit measure for the model using those
    variables
  }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au}.
}

\references{
  Hatt, B. E., Fletcher, T. D., Walsh, C. J. and Taylor, S. L. 2004 The
  influence of urban density and drainage infrastructure on the
  concentrations and loads of pollutants in small
  streams. \emph{Environmental Management} \bold{34}, 112--124.
  
  Walsh, C. J., Papas, P. J., Crowther, D., Sim, P. T., and Yoo, J. 2004
  Stormwater drainage pipes as a threat to a stream-dwelling amphipod of
  conservation significance, \emph{Austrogammarus australis}, in southeastern
  Australia. \emph{Biodiversity and Conservation} \bold{13}, 781--793.
 }

 \seealso{
  \code{\link{hier.part}}, \code{\link{partition}}, \code{\link{rand.hp}}
  }
 \examples{
           #linear regression of log(electrical conductivity) in streams
           #against seven independent variables describing catchment
           #characteristics (from Hatt et al. 2004)
           data(urbanwq)
           env <- urbanwq[,2:8]
           all.regs(urbanwq$lec, env, fam = "gaussian", gof = "Rsqu",
           print.vars = TRUE)

           #logistic regression of an amphipod species occurrence in
           #streams against four independent variables describing
           #catchment characteristics (from Walsh et al. 2004)
           data(amphipod)
           env1 <- amphipod[,2:5]
           all.regs(amphipod$australis, env1, fam = "binomial",
	   gof = "logLik", print.vars = TRUE)
}
\keyword{}


\eof
\name{combos}
\alias{combos}
\title{
  All combinations of a hierarchy of models of n variables
}
\description{
  Lists a matrix of combinations of 1 to n variables in ascending order
}
\usage{
  combos(n)
}
\arguments{
  \item{n}{
    an integer: the number of variables
  }
  }

\details{
Lists hierarchy of all possible combinations of n variables in ascending
order, starting with 1 variable, then all combinations of 2 variables,
and so on until the one combination with all n variables.  This function
is used by \code{all.regs} to structure the models required for
hierarchical partioning.  This function requires the gtools package in
the gregmisc bundle.
}

\value{
  a list containing
  \item{ragged}{
    a matrix with zeroes in empty elements and 1 in column 1, 2 in
    column 2 ... n in column n for full elements
  }

  \item{binary}{
    a matrix as for ragged, but with 1 in all full elements
    }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} 
}

\seealso{
  \code{\link{all.regs}}
  }

\keyword{}


\eof
\name{hier.part}
\alias{hier.part}
\title{
  Goodness of fit calculation and hierarchical partitioning
}
\description{
  Partitions variance in a multivariate dataset
}
\usage{
hier.part(y, xcan, family = "gaussian", gof = "RMSPE", barplot = TRUE)
}
\arguments{
  \item{y}{
    a vector containing the dependent variables
  }
  
  \item{xcan}{
    a dataframe containing the n independent variables
  }
  
  \item{family}{
    family argument of \code{glm}
  }

  \item{gof}{
    Goodness-of-fit measure.  Currently "RMSPE", Root-mean-square
    'prediction' error, "logLik", Log-Likelihood or "Rsqu", R-squared
    }

    \item{barplot}{
    If TRUE, a barplot of I and J for each variable is plotted expressed
    as percentage of total explained variance.
    }
  }

\details{
This function calculates goodness of fit measures for the entire
hierarchy of models using all combinations of N independent variables
using the function \code{all.regs}.  It takes the list of goodness
of fit measures and, using the \code{partition} function, applies the
hierarchical partitioning algorithm of Chevan and Sutherland (1991)
to return a simple table listing each variable, its independent
contribution (I) and its conjoint contribution with all other variables
(J).

Note earlier versions of hier.part (<1.0) produced a matrix and barplot
of percentage distribution of effects as a percentage of the sum of all
Is and Js, as portrayed in Hatt et al. (2004) and Walsh et al. (2004).
This version plots the percentage distribution of independent effects
only. The sum of Is equals the goodness of fit measure of the full model
minus the goodness of fit measure of the null model.

The distribution of joint effects shows the relative contribution of
each variable to shared variability in the full model. Negative joint
effects are possible for variables that act as suppressors of other
variables (Chevan and Sutherland 1991).

At this stage, the partition routine will not run for more than 12
independent variables. This function requires the gtools package in
the gregmisc bundle 
}

\value{
  a list containing
  \item{gfs}{
    a data frame or vector listing all combinations of independent
    variables in the first column in ascending order, and the
    corresponding goodness of fit measure for the model using those
    variables
  }

  \item{IJ}{
    a data frame of I, the independent and J the joint
    contribution for each independent variable
  }

  \item{I.perc}{
    a data frame of I as a percentage of total explained variance
  }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} using c and fortran
  code written by Ralph MacNally \email{Ralph.MacNally@sci.monash.edu.au}.
}
\references{
  Chevan, A. and Sutherland, M. 1991 Hierarchical Partitioning. \emph{The
  American Statistician} \bold{45}, 90--96.

  Hatt, B. E., Fletcher, T. D., Walsh, C. J. and Taylor, S. L. 2004 The
  influence of urban density and drainage infrastructure on the
  concentrations and loads of pollutants in small
  streams. \emph{Environmental Management} \bold{34}, 112--124.
  
  Mac Nally, R. 2000 Regression and model building in conservation
  biology, biogeography and ecology: the distinction between and
  reconciliation of 'predictive' and 'explanatory' models. \emph{Biodiversity
  and Conservation} \bold{9}, 655--671.

  Walsh, C. J., Papas, P. J., Crowther, D., Sim, P. T., and Yoo, J. 2004
  Stormwater drainage pipes as a threat to a stream-dwelling amphipod of
  conservation significance, \emph{Austrogammarus australis}, in south-eastern
  Australia. \emph{Biodiversity and Conservation} \bold{13}, 781--793.
}
 \seealso{
  \code{\link{all.regs}}, \code{\link{partition}}, \code{\link{rand.hp}}
  }
 \examples{
           #linear regression of log(electrical conductivity) in streams
           #against seven independent variables describing catchment
           #characteristics (from Hatt et al. 2004)
           data(urbanwq)
           env <- urbanwq[,2:8]
           hier.part(urbanwq$lec, env, fam = "gaussian", gof = "Rsqu")

           #logistic regression of an amphipod species occurrence in
           #streams against four independent variables describing
           #catchment characteristics (from Walsh et al. 2004)
           data(amphipod)
           env1 <- amphipod[,2:5]
           hier.part(amphipod$australis, env1, fam = "binomial", gof = "logLik")
}
\keyword{}


\eof
\name{hier.part.data}
\alias{urbanwq}
\alias{amphipod}
\alias{chevan}
\title{
  Example data for hier.part
}
\description{
  Example data sets for hier.part package.
  }
\usage{
  data(urbanwq)
  data(amphipod)
  data(chevan)
}
\details{
    urbanwq.txt

    Seven catchment variables (fimp, catchment imperviousness\eqn{^{0.25}};
    sconn, drainage connection\eqn{^{0.5}}; sdensep, septic tank
    density\eqn{^{0.5}}; unsealden, unsealed road density; fcarea,
    catchment area\eqn{^{0.25}}; selev, elevation\eqn{^{0.5}}; amgeast,
    longitude) and median baseflow concentrations of three water quality
    variables in sixteen streams draining 16 independent subcatchments
    (ldoc, log(dissolved organic carbon); lec, log(electrical
    conductivity); lnox, log(nitrate/nitrite). Data from Hatt et
    al. (2004).
        
    amphipod.txt

    Presence-absence data for a stream-dwelling amphipod (australis) in
    58 sites, with four catchment variables (fimp, imperviousness\eqn{^{0.25}};
    fconn, drainage connection\eqn{^{0.25}}; densep, density of septic
    tanks; unseal, unsealed road density).  Data from Walsh et al. (2004).
    
    chevan.txt

    Chi-squared (chisq) and R-squared (rsqu) for logistic and linear
    regression example from Chevan and Sutherland (1991)
}
\references{
  Chevan, A. and Sutherland, M. 1991 Hierarchical Partitioning. \emph{The
  American Statistician} \bold{45}, 90--96.

  Hatt, B. E., Fletcher, T. D., Walsh, C. J. and Taylor, S. L. 2004 The
  influence of urban density and drainage infrastructure on the
  concentrations and loads of pollutants in small
  streams. \emph{Environmental Management} \bold{34}, 112--124.
  
  Walsh, C. J., Papas, P. J., Crowther, D., Sim, P. T., and Yoo, J. 2004
  Stormwater drainage pipes as a threat to a stream-dwelling amphipod of
  conservation significance, \emph{Austrogammarus australis}, in southeastern
  Australia. \emph{Biodiversity and Conservation} \bold{13}, 781--793.

}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au}
}
\keyword{datasets}








\eof
\name{hier.part.internal}
\alias{combos1}
\alias{current.model}

\title{
  Internal functions for hier.part
}
\description{
  Internal functions for hier.part
}
\keyword{internal}

\eof
\name{partition}
\alias{partition}
\title{
  Hierarchical partitioning from a list of goodness of fit measures 
}
\description{
  Partitions variance in a multivariate dataset from a list of goodness
  of fit measures
}
\usage{
partition(gfs, pcan, var.names = NULL)
}
\arguments{
  \item{gfs}{
    an array as outputted by the function \code{all.regs} or a vector of
    goodness of fit measures from a hierarchy of regressions based on pcan
    variables in ascending order (as produced by function \code{combos},
    but also including the null model as the first element)
  }
  
  \item{pcan}{
    the number of variables from which the hierarchy was constructed
    (maximum = 12)
  }
  
  \item{var.names}{
    an array of pcan variable names, if required
  }
  }

\details{
This function applies the hierarchical partitioning algorithm of Chevan
and Sutherland (1991) to return a simple table listing of each variable,
its independent contribution (I) and its conjoint contribution with all
other variables (J).  The output is identical to the function
\code{hier.part}, which takes the dependent and independent variable
data as its input.

Note earlier versions of partition (hier.part<1.0) produced a matrix and
barplot of percentage distribution of effects as a percentage of the sum
of all Is and Js, as portrayed in Hatt et al. (2004) and Walsh et al.
(2004). This version plots the percentage distribution of independent
effects only. The sum of Is equals the goodness of fit measure of the
full model minus the goodness of fit measure of the null model.

The distribution of joint effects shows the relative contribution of
each variable to shared variability in the full model. Negative joint
effects are possible for variables that act as suppressors of other
variables (Chevan and Sutherland 1991).

At this stage, the partition routine will not run for more than 12
independent variables. This function requires the gtools package in the
gregmisc bundle
}

\value{
  a list containing
  \item{gfs}{
    a data frame listing all combinations of independent
    variables in the first column in ascending order, and the
    corresponding goodness of fit measure for the model using those
    variables
  }

  \item{IJ}{
    a data frame of I, the independent and J the joint
    contribution for each independent variable
  }

  \item{I.perc}{
    a data frame of I as a percentage of total explained variance
  }
  
  \item{J.perc}{
    a data frame of J as a percentage of sum of all Js
  }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} using c and fortran
  code written by Ralph MacNally \email{Ralph.MacNally@sci.monash.edu.au}.
}
\references{
  Chevan, A. and Sutherland, M. 1991 Hierarchical Partitioning. \emph{The
  American Statistician} \bold{45}, 90--96.

  Hatt, B. E., Fletcher, T. D., Walsh, C. J. and Taylor, S. L. 2004 The
  influence of urban density and drainage infrastructure on the
  concentrations and loads of pollutants in small
  streams. \emph{Environmental Management} \bold{34}, 112--124.
 }
\seealso{
  \code{\link{all.regs}}, \code{\link{partition}}, \code{\link{rand.hp}}
  }
 \examples{
           #linear regression of log(electrical conductivity) in streams
           #against seven independent variables describing catchment
           #characteristics (from Hatt et al. 2004)
           data(urbanwq)
           env <- urbanwq[,2:8]
           gofs <- all.regs(urbanwq$lec, env, fam = "gaussian",
           gof = "Rsqu", print.vars = TRUE)
           partition(gofs, pcan = 7, var.names = names(urbanwq[,2,8]))

           #hierarchical partitioning of logistic and linear regression
           #goodness of fit measures from Chevan and Sutherland (1991) 
           data(chevan)
           partition(chevan$chisq, pcan = 4)
           partition(chevan$rsqu, pcan = 4)
}
\keyword{}


\eof
\name{rand.hp}
\alias{rand.hp}
\title{
  Randomization test for hierarchical partitioning
}
\description{
  Randomizes elements in each column in xcan and recalculates
  \code{hier.part} num.reps times
}
\usage{
 rand.hp(y, xcan, family = "gaussian", gof = "RMSPE",
                    num.reps = 100)
}
\arguments{
  \item{y}{
    a vector containing the dependent variables
  }
  
  \item{xcan}{
    a dataframe containing the n independent variables
  }
  
  \item{family}{
    family argument of \code{glm}
  }

  \item{gof}{
    Goodness-of-fit measure.  Currently "RMSPE", Root-mean-square
    'Prediction' error, "NLL", Negative log Likelihood or "Rsqu",
    R-squared
  }

  \item{num.reps}{
    Number of repeated randomizations
    }
  }

\details{
This function is a randomization routine for the \code{hier.part}
function which returns a matrix of I values (the independent
contribution towards explained variance in a multivariate dataset) for
all values from "num.reps" randomizations. For each randomization, the
values in each variable (i.e each column of xcan) are randomized
independently, and hier.part is run on the randomized xcan.  As well as
the randomized I matrix, the function returns a summary table listing
the observed I values, the 95th and 99th percentile values of I for
the randomized dataset.   
}

\value{
  a list containing
  \item{Irands}{
    matrix of num.reps + 1  rows of I values for each dependent
    variable.  The first row contains the observed I values and the
    remaining num.reps rows contains the I values returned for each
    randomization.  
  }
  \item{Iprobs}{
    data.frame of observed I values for each variable, Z-scores for the
    generated distribution of randomized Is and an indication of
    statistical significance.  Z-scores are cacluated as
    (observed - mean(randomizations))/sd(randomizations),
    and statistical significance (*) is based on upper 0.95 confidence
    limit (\eqn{Z >= 1.65}).
    }
}
\author{
  Chris Walsh \email{Chris.Walsh@sci.monash.edu.au}.
}
\references{
  Hatt, B. E., Fletcher, T. D., Walsh, C. J. and Taylor, S. L. 2004 The
  influence of urban density and drainage infrastructure on the
  concentrations and loads of pollutants in small
  streams. \emph{Environmental Management} \bold{34}, 112--124.
  
  Mac Nally, R. 2000 Regression and model building in conservation
  biology, biogeography and ecology: the distinction between and
  reconciliation of 'predictive' and 'explanatory' models. \emph{Biodiversity
  and Conservation} \bold{9}, 655--671.

  MacNally, R. 2002 Multiple regression and inference in conservation
  biology and ecology: further comments on identifying important
  predictor variables. \emph{Biodiversity and Conservation} \bold{11},
  1397--1401.

  Walsh, C. J., Papas, P. J., Crowther, D., Sim, P. T., and Yoo, J. 2004
  Stormwater drainage pipes as a threat to a stream-dwelling amphipod of
  conservation significance, \emph{Austrogammarus australis}, in southeastern
  Australia. \emph{Biodiversity and Conservation} \bold{13}, 781--793.
}

\seealso{
  \code{\link{hier.part}}, \code{\link{partition}}
  }
  \examples{
           #linear regression of log(electrical conductivity) in streams
           #against four independent variables describing catchment
           #characteristics (from Hatt et al. 2004)
           data(urbanwq)
           env <- urbanwq[,2:5]
           rand.hp(urbanwq$lec, env, fam = "gaussian", gof = "Rsqu")$Iprobs

           #logistic regression of an amphipod species occurrence in
           #streams against four independent variables describing
           #catchment characteristics (from Walsh et al. 2004)
           data(amphipod)
           env1 <- amphipod[,2:5]
           rand.hp(amphipod$australis, env1, fam = "binomial",
           gof = "logLik")$Iprobs
}

\keyword{}


\eof
